"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Config = void 0;
const BaseConfig_1 = require("./BaseConfig");
const bud_support_1 = require("@roots/bud-support");
/**
 * Babel API
 */
class Config extends BaseConfig_1.BaseConfig {
    /**
     * Initialize
     */
    init(app) {
        this.app = app;
        this.log = app.logger.instance.scope(this.name);
        return this;
    }
    /**
     * Normalize entry
     */
    normalizeEntry(c) {
        return bud_support_1.isString(c) ? [c, {}] : c;
    }
    /**
     * Set a babel plugin
     */
    setPlugin(plugin) {
        this.app.log(`Setting babel plugin: ${plugin}`);
        plugin = this.normalizeEntry(plugin);
        this.plugins = Object.assign(Object.assign({}, this.plugins), { [plugin[0]]: plugin });
        return this;
    }
    /**
     * Set babel plugins
     */
    setPlugins(plugins) {
        plugins.map(this.setPlugin);
        return this;
    }
    /**
     * Set a babel preset
     */
    setPreset(preset) {
        this.app.log(`Setting babel preset: ${preset}`);
        preset = this.normalizeEntry(preset);
        this.presets = Object.assign(Object.assign({}, this.presets), { [preset[0]]: preset });
        return this;
    }
    /**
     * Set babel presets
     */
    setPresets(presets) {
        presets.map(this.setPreset);
        return this;
    }
    /**
     * Unset a babel preset
     */
    unsetPreset(preset) {
        !this.presets[preset]
            ? this.log.error(`${preset} not found`, this.presets)
            : delete this.presets[preset];
        return this;
    }
    /**
     * Unset a babel plugin
     */
    unsetPlugin(plugin) {
        !this.plugins[plugin]
            ? this.log.error(`${plugin} not found`, this.plugins)
            : delete this.plugins[plugin];
        return this;
    }
    /**
     * Set a babel plugin's options
     */
    setPluginOptions(plugin, options) {
        this.plugins[plugin] = [this.plugins[plugin][0], options];
        return this;
    }
    /**
     * Set a babel preset's options
     */
    setPresetOptions(preset, options) {
        this.presets[preset] = [this.presets[preset][0], options];
        return this;
    }
}
__decorate([
    bud_support_1.bind
], Config.prototype, "init", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "normalizeEntry", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "setPlugin", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "setPlugins", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "setPreset", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "setPresets", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "unsetPreset", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "unsetPlugin", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "setPluginOptions", null);
__decorate([
    bud_support_1.bind
], Config.prototype, "setPresetOptions", null);
exports.Config = Config;
//# sourceMappingURL=index.js.map